# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/access_analyzer_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/access_analyzer_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.iam.v1 import resource_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_resource__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/iam/v1/access_analyzer_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a\"yandex/cloud/iam/v1/resource.proto\x1a\x1dyandex/cloud/validation.proto\"\xab\x01\n ListSubjectAccessBindingsRequest\x12!\n\nsubject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12%\n\x0forganization_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"\x88\x01\n!ListSubjectAccessBindingsResponse\x12J\n\x17subject_access_bindings\x18\x01 \x03(\x0b\x32).yandex.cloud.iam.v1.SubjectAccessBinding\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"l\n\x14SubjectAccessBinding\x12\x0f\n\x07role_id\x18\x01 \x01(\t\x12/\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.iam.v1.Resource\x12\x12\n\nsubject_id\x18\x03 \x01(\t2\xcf\x01\n\x15\x41\x63\x63\x65ssAnalyzerService\x12\xb5\x01\n\x19ListSubjectAccessBindings\x12\x35.yandex.cloud.iam.v1.ListSubjectAccessBindingsRequest\x1a\x36.yandex.cloud.iam.v1.ListSubjectAccessBindingsResponse\")\x82\xd3\xe4\x93\x02#\x12!/iam/v1/listSubjectAccessBindingsBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.access_analyzer_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['subject_id']._loaded_options = None
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['subject_id']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_ACCESSANALYZERSERVICE'].methods_by_name['ListSubjectAccessBindings']._loaded_options = None
  _globals['_ACCESSANALYZERSERVICE'].methods_by_name['ListSubjectAccessBindings']._serialized_options = b'\202\323\344\223\002#\022!/iam/v1/listSubjectAccessBindings'
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST']._serialized_start=172
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST']._serialized_end=343
  _globals['_LISTSUBJECTACCESSBINDINGSRESPONSE']._serialized_start=346
  _globals['_LISTSUBJECTACCESSBINDINGSRESPONSE']._serialized_end=482
  _globals['_SUBJECTACCESSBINDING']._serialized_start=484
  _globals['_SUBJECTACCESSBINDING']._serialized_end=592
  _globals['_ACCESSANALYZERSERVICE']._serialized_start=595
  _globals['_ACCESSANALYZERSERVICE']._serialized_end=802
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.speechsense.v1.assistant_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListAssistantsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """Project id"""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___ListAssistantsRequest = ListAssistantsRequest

@typing.final
class ListAssistantsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSISTANTS_FIELD_NUMBER: builtins.int
    @property
    def assistants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.speechsense.v1.assistant_pb2.Assistant]:
        """Assistants belonging to the given project"""

    def __init__(
        self,
        *,
        assistants: collections.abc.Iterable[yandex.cloud.speechsense.v1.assistant_pb2.Assistant] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["assistants", b"assistants"]) -> None: ...

global___ListAssistantsResponse = ListAssistantsResponse

@typing.final
class ListModelsRequest(google.protobuf.message.Message):
    """No parameters"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListModelsRequest = ListModelsRequest

@typing.final
class ListModelsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODELS_FIELD_NUMBER: builtins.int
    @property
    def models(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.speechsense.v1.assistant_pb2.Model]: ...
    def __init__(
        self,
        *,
        models: collections.abc.Iterable[yandex.cloud.speechsense.v1.assistant_pb2.Model] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["models", b"models"]) -> None: ...

global___ListModelsResponse = ListModelsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/userpool.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/userpool.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/organizationmanager/v1/idp/userpool.proto\x12\'yandex.cloud.organizationmanager.v1.idp\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xd2\x06\n\x08Userpool\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12M\n\x06labels\x18\x05 \x03(\x0b\x32=.yandex.cloud.organizationmanager.v1.idp.Userpool.LabelsEntry\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x64omains\x18\x08 \x03(\t\x12H\n\x06status\x18\t \x01(\x0e\x32\x38.yandex.cloud.organizationmanager.v1.idp.Userpool.Status\x12L\n\ruser_settings\x18\n \x01(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.idp.UserSettings\x12_\n\x17password_quality_policy\x18\x0b \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.PasswordQualityPolicy\x12\x61\n\x18password_lifetime_policy\x18\x0c \x01(\x0b\x32?.yandex.cloud.organizationmanager.v1.idp.PasswordLifetimePolicy\x12i\n\x1c\x62ruteforce_protection_policy\x18\r \x01(\x0b\x32\x43.yandex.cloud.organizationmanager.v1.idp.BruteforceProtectionPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\"\x8f\x01\n\x0cUserSettings\x12 \n\x18\x61llow_edit_self_password\x18\x01 \x01(\x08\x12\x1c\n\x14\x61llow_edit_self_info\x18\x02 \x01(\x08\x12 \n\x18\x61llow_edit_self_contacts\x18\x03 \x01(\x08\x12\x1d\n\x15\x61llow_edit_self_login\x18\x04 \x01(\x08\"\xb6\x03\n\x06\x44omain\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x46\n\x06status\x18\x02 \x01(\x0e\x32\x36.yandex.cloud.organizationmanager.v1.idp.Domain.Status\x12\x13\n\x0bstatus_code\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0cvalidated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12L\n\nchallenges\x18\x07 \x03(\x0b\x32\x38.yandex.cloud.organizationmanager.v1.idp.DomainChallenge\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\"l\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10NEED_TO_VALIDATE\x10\x01\x12\x0e\n\nVALIDATING\x10\x02\x12\t\n\x05VALID\x10\x03\x12\x0b\n\x07INVALID\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05J\x04\x08\x06\x10\x07\"\xaa\x05\n\x0f\x44omainChallenge\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12K\n\x04type\x18\x04 \x01(\x0e\x32=.yandex.cloud.organizationmanager.v1.idp.DomainChallenge.Type\x12O\n\x06status\x18\x05 \x01(\x0e\x32?.yandex.cloud.organizationmanager.v1.idp.DomainChallenge.Status\x12[\n\rdns_challenge\x18\x06 \x01(\x0b\x32\x42.yandex.cloud.organizationmanager.v1.idp.DomainChallenge.DnsRecordH\x00\x1a\xa6\x01\n\tDnsRecord\x12\x0c\n\x04name\x18\x01 \x01(\t\x12U\n\x04type\x18\x02 \x01(\x0e\x32G.yandex.cloud.organizationmanager.v1.idp.DomainChallenge.DnsRecord.Type\x12\r\n\x05value\x18\x03 \x01(\t\"%\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03TXT\x10\x01\")\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x44NS_TXT\x10\x01\"U\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\t\n\x05VALID\x10\x03\x12\x0b\n\x07INVALID\x10\x04\x42\x0b\n\tchallengeJ\x04\x08\x03\x10\x04\"\xa5\x04\n\x15PasswordQualityPolicy\x12\x15\n\rallow_similar\x18\x01 \x01(\x08\x12\x1b\n\nmax_length\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x1b\n\nmin_length\x18\x03 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x1d\n\x0cmatch_length\x18\x04 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12h\n\x10required_classes\x18\x05 \x01(\x0b\x32N.yandex.cloud.organizationmanager.v1.idp.PasswordQualityPolicy.RequiredClasses\x12}\n\x1cmin_length_by_class_settings\x18\x06 \x01(\x0b\x32W.yandex.cloud.organizationmanager.v1.idp.PasswordQualityPolicy.MinLengthByClassSettings\x1aS\n\x0fRequiredClasses\x12\x0e\n\x06lowers\x18\x01 \x01(\x08\x12\x0e\n\x06uppers\x18\x02 \x01(\x08\x12\x0e\n\x06\x64igits\x18\x03 \x01(\x08\x12\x10\n\x08specials\x18\x04 \x01(\x08\x1a^\n\x18MinLengthByClassSettings\x12\x14\n\x03one\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x14\n\x03two\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x16\n\x05three\x18\x03 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\"Z\n\x16PasswordLifetimePolicy\x12\x1f\n\x0emin_days_count\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x1f\n\x0emax_days_count\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\"\x8b\x01\n\x1a\x42ruteforceProtectionPolicy\x12)\n\x06window\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12(\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x18\n\x08\x61ttempts\x18\x03 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0B~\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.userpool_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idp'
  _globals['_USERPOOL_LABELSENTRY']._loaded_options = None
  _globals['_USERPOOL_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS'].fields_by_name['one']._loaded_options = None
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS'].fields_by_name['one']._serialized_options = b'\372\3071\003>=0'
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS'].fields_by_name['two']._loaded_options = None
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS'].fields_by_name['two']._serialized_options = b'\372\3071\003>=0'
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS'].fields_by_name['three']._loaded_options = None
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS'].fields_by_name['three']._serialized_options = b'\372\3071\003>=0'
  _globals['_PASSWORDQUALITYPOLICY'].fields_by_name['max_length']._loaded_options = None
  _globals['_PASSWORDQUALITYPOLICY'].fields_by_name['max_length']._serialized_options = b'\372\3071\003>=0'
  _globals['_PASSWORDQUALITYPOLICY'].fields_by_name['min_length']._loaded_options = None
  _globals['_PASSWORDQUALITYPOLICY'].fields_by_name['min_length']._serialized_options = b'\372\3071\003>=0'
  _globals['_PASSWORDQUALITYPOLICY'].fields_by_name['match_length']._loaded_options = None
  _globals['_PASSWORDQUALITYPOLICY'].fields_by_name['match_length']._serialized_options = b'\372\3071\003>=0'
  _globals['_PASSWORDLIFETIMEPOLICY'].fields_by_name['min_days_count']._loaded_options = None
  _globals['_PASSWORDLIFETIMEPOLICY'].fields_by_name['min_days_count']._serialized_options = b'\372\3071\003>=0'
  _globals['_PASSWORDLIFETIMEPOLICY'].fields_by_name['max_days_count']._loaded_options = None
  _globals['_PASSWORDLIFETIMEPOLICY'].fields_by_name['max_days_count']._serialized_options = b'\372\3071\003>=0'
  _globals['_BRUTEFORCEPROTECTIONPOLICY'].fields_by_name['attempts']._loaded_options = None
  _globals['_BRUTEFORCEPROTECTIONPOLICY'].fields_by_name['attempts']._serialized_options = b'\372\3071\002>0'
  _globals['_USERPOOL']._serialized_start=196
  _globals['_USERPOOL']._serialized_end=1046
  _globals['_USERPOOL_LABELSENTRY']._serialized_start=927
  _globals['_USERPOOL_LABELSENTRY']._serialized_end=972
  _globals['_USERPOOL_STATUS']._serialized_start=974
  _globals['_USERPOOL_STATUS']._serialized_end=1046
  _globals['_USERSETTINGS']._serialized_start=1049
  _globals['_USERSETTINGS']._serialized_end=1192
  _globals['_DOMAIN']._serialized_start=1195
  _globals['_DOMAIN']._serialized_end=1633
  _globals['_DOMAIN_STATUS']._serialized_start=1519
  _globals['_DOMAIN_STATUS']._serialized_end=1627
  _globals['_DOMAINCHALLENGE']._serialized_start=1636
  _globals['_DOMAINCHALLENGE']._serialized_end=2318
  _globals['_DOMAINCHALLENGE_DNSRECORD']._serialized_start=2003
  _globals['_DOMAINCHALLENGE_DNSRECORD']._serialized_end=2169
  _globals['_DOMAINCHALLENGE_DNSRECORD_TYPE']._serialized_start=2132
  _globals['_DOMAINCHALLENGE_DNSRECORD_TYPE']._serialized_end=2169
  _globals['_DOMAINCHALLENGE_TYPE']._serialized_start=2171
  _globals['_DOMAINCHALLENGE_TYPE']._serialized_end=2212
  _globals['_DOMAINCHALLENGE_STATUS']._serialized_start=2214
  _globals['_DOMAINCHALLENGE_STATUS']._serialized_end=2299
  _globals['_PASSWORDQUALITYPOLICY']._serialized_start=2321
  _globals['_PASSWORDQUALITYPOLICY']._serialized_end=2870
  _globals['_PASSWORDQUALITYPOLICY_REQUIREDCLASSES']._serialized_start=2691
  _globals['_PASSWORDQUALITYPOLICY_REQUIREDCLASSES']._serialized_end=2774
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS']._serialized_start=2776
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS']._serialized_end=2870
  _globals['_PASSWORDLIFETIMEPOLICY']._serialized_start=2872
  _globals['_PASSWORDLIFETIMEPOLICY']._serialized_end=2962
  _globals['_BRUTEFORCEPROTECTIONPOLICY']._serialized_start=2965
  _globals['_BRUTEFORCEPROTECTIONPOLICY']._serialized_end=3104
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/userpool_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/userpool_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.idp import userpool_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_userpool__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/organizationmanager/v1/idp/userpool_service.proto\x12\'yandex.cloud.organizationmanager.v1.idp\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x36yandex/cloud/organizationmanager/v1/idp/userpool.proto\x1a\x1dyandex/cloud/validation.proto\x1a google/protobuf/field_mask.proto\"7\n\x12GetUserpoolRequest\x12!\n\x0buserpool_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x98\x01\n\x14ListUserpoolsRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"v\n\x15ListUserpoolsResponse\x12\x44\n\tuserpools\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.organizationmanager.v1.idp.Userpool\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x84\x06\n\x15\x43reateUserpoolRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x04name\x18\x02 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x97\x01\n\x06labels\x18\x04 \x03(\x0b\x32J.yandex.cloud.organizationmanager.v1.idp.CreateUserpoolRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\'\n\x11\x64\x65\x66\x61ult_subdomain\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\x12L\n\ruser_settings\x18\x06 \x01(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.idp.UserSettings\x12_\n\x17password_quality_policy\x18\x07 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.PasswordQualityPolicy\x12\x61\n\x18password_lifetime_policy\x18\x08 \x01(\x0b\x32?.yandex.cloud.organizationmanager.v1.idp.PasswordLifetimePolicy\x12i\n\x1c\x62ruteforce_protection_policy\x18\t \x01(\x0b\x32\x43.yandex.cloud.organizationmanager.v1.idp.BruteforceProtectionPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16\x43reateUserpoolMetadata\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\"\x85\x06\n\x15UpdateUserpoolRequest\x12!\n\x0buserpool_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x97\x01\n\x06labels\x18\x05 \x03(\x0b\x32J.yandex.cloud.organizationmanager.v1.idp.UpdateUserpoolRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12L\n\ruser_settings\x18\x06 \x01(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.idp.UserSettings\x12_\n\x17password_quality_policy\x18\x07 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.PasswordQualityPolicy\x12\x61\n\x18password_lifetime_policy\x18\x08 \x01(\x0b\x32?.yandex.cloud.organizationmanager.v1.idp.PasswordLifetimePolicy\x12i\n\x1c\x62ruteforce_protection_policy\x18\t \x01(\x0b\x32\x43.yandex.cloud.organizationmanager.v1.idp.BruteforceProtectionPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16UpdateUserpoolMetadata\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\":\n\x15\x44\x65leteUserpoolRequest\x12!\n\x0buserpool_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteUserpoolMetadata\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\"?\n\x18GetUserpoolDomainRequest\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"\x8c\x01\n\x1aListUserpoolDomainsRequest\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"x\n\x1bListUserpoolDomainsResponse\x12@\n\x07\x64omains\x18\x01 \x03(\x0b\x32/.yandex.cloud.organizationmanager.v1.idp.Domain\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"?\n\x18\x41\x64\x64UserpoolDomainRequest\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"@\n\x19\x41\x64\x64UserpoolDomainMetadata\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"D\n\x1dValidateUserpoolDomainRequest\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"E\n\x1eValidateUserpoolDomainMetadata\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"B\n\x1b\x44\x65leteUserpoolDomainRequest\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"C\n\x1c\x44\x65leteUserpoolDomainMetadata\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"}\n\x1dListUserpoolOperationsRequest\x12\x1d\n\x0buserpool_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"p\n\x1eListUserpoolOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xeb\x18\n\x0fUserpoolService\x12\xb3\x01\n\x03Get\x12;.yandex.cloud.organizationmanager.v1.idp.GetUserpoolRequest\x1a\x31.yandex.cloud.organizationmanager.v1.idp.Userpool\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/organization-manager/v1/idp/userpools/{userpool_id}\x12\xb5\x01\n\x04List\x12=.yandex.cloud.organizationmanager.v1.idp.ListUserpoolsRequest\x1a>.yandex.cloud.organizationmanager.v1.idp.ListUserpoolsResponse\".\x82\xd3\xe4\x93\x02(\x12&/organization-manager/v1/idp/userpools\x12\xc4\x01\n\x06\x43reate\x12>.yandex.cloud.organizationmanager.v1.idp.CreateUserpoolRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*\"\n\x16\x43reateUserpoolMetadata\x12\x08Userpool\x82\xd3\xe4\x93\x02+\"&/organization-manager/v1/idp/userpools:\x01*\x12\xd2\x01\n\x06Update\x12>.yandex.cloud.organizationmanager.v1.idp.UpdateUserpoolRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*\"\n\x16UpdateUserpoolMetadata\x12\x08Userpool\x82\xd3\xe4\x93\x02\x39\x32\x34/organization-manager/v1/idp/userpools/{userpool_id}:\x01*\x12\xdc\x01\n\x06\x44\x65lete\x12>.yandex.cloud.organizationmanager.v1.idp.DeleteUserpoolRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*/\n\x16\x44\x65leteUserpoolMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36*4/organization-manager/v1/idp/userpools/{userpool_id}\x12\xce\x01\n\tGetDomain\x12\x41.yandex.cloud.organizationmanager.v1.idp.GetUserpoolDomainRequest\x1a/.yandex.cloud.organizationmanager.v1.idp.Domain\"M\x82\xd3\xe4\x93\x02G\x12\x45/organization-manager/v1/idp/userpools/{userpool_id}/domains/{domain}\x12\xde\x01\n\x0bListDomains\x12\x43.yandex.cloud.organizationmanager.v1.idp.ListUserpoolDomainsRequest\x1a\x44.yandex.cloud.organizationmanager.v1.idp.ListUserpoolDomainsResponse\"D\x82\xd3\xe4\x93\x02>\x12</organization-manager/v1/idp/userpools/{userpool_id}/domains\x12\xe1\x01\n\tAddDomain\x12\x41.yandex.cloud.organizationmanager.v1.idp.AddUserpoolDomainRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*#\n\x19\x41\x64\x64UserpoolDomainMetadata\x12\x06\x44omain\x82\xd3\xe4\x93\x02\x41\"</organization-manager/v1/idp/userpools/{userpool_id}/domains:\x01*\x12\x83\x02\n\x0eValidateDomain\x12\x46.yandex.cloud.organizationmanager.v1.idp.ValidateUserpoolDomainRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2*(\n\x1eValidateUserpoolDomainMetadata\x12\x06\x44omain\x82\xd3\xe4\x93\x02S\"N/organization-manager/v1/idp/userpools/{userpool_id}/domains/{domain}:validate:\x01*\x12\x80\x02\n\x0c\x44\x65leteDomain\x12\x44.yandex.cloud.organizationmanager.v1.idp.DeleteUserpoolDomainRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\xb2\xd2*5\n\x1c\x44\x65leteUserpoolDomainMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02G*E/organization-manager/v1/idp/userpools/{userpool_id}/domains/{domain}\x12\xea\x01\n\x0eListOperations\x12\x46.yandex.cloud.organizationmanager.v1.idp.ListUserpoolOperationsRequest\x1aG.yandex.cloud.organizationmanager.v1.idp.ListUserpoolOperationsResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/organization-manager/v1/idp/userpools/{userpool_id}/operations\x12\xc6\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"O\x82\xd3\xe4\x93\x02I\x12G/organization-manager/v1/idp/userpools/{resource_id}:listAccessBindings\x12\x85\x02\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x9d\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02K\"F/organization-manager/v1/idp/userpools/{resource_id}:setAccessBindings:\x01*\x12\x91\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\xa3\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02N2I/organization-manager/v1/idp/userpools/{resource_id}:updateAccessBindings:\x01*B~\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idp'
  _globals['_GETUSERPOOLREQUEST'].fields_by_name['userpool_id']._loaded_options = None
  _globals['_GETUSERPOOLREQUEST'].fields_by_name['userpool_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEUSERPOOLREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEUSERPOOLREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['default_subdomain']._loaded_options = None
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['default_subdomain']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_UPDATEUSERPOOLREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEUSERPOOLREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['userpool_id']._loaded_options = None
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['userpool_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEUSERPOOLREQUEST'].fields_by_name['userpool_id']._loaded_options = None
  _globals['_DELETEUSERPOOLREQUEST'].fields_by_name['userpool_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTUSERPOOLDOMAINSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERPOOLDOMAINSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTUSERPOOLDOMAINSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSERPOOLDOMAINSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTUSERPOOLDOMAINSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTUSERPOOLDOMAINSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTUSERPOOLOPERATIONSREQUEST'].fields_by_name['userpool_id']._loaded_options = None
  _globals['_LISTUSERPOOLOPERATIONSREQUEST'].fields_by_name['userpool_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTUSERPOOLOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERPOOLOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTUSERPOOLOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSERPOOLOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_USERPOOLSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0026\0224/organization-manager/v1/idp/userpools/{userpool_id}'
  _globals['_USERPOOLSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002(\022&/organization-manager/v1/idp/userpools'
  _globals['_USERPOOLSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateUserpoolMetadata\022\010Userpool\202\323\344\223\002+\"&/organization-manager/v1/idp/userpools:\001*'
  _globals['_USERPOOLSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateUserpoolMetadata\022\010Userpool\202\323\344\223\002924/organization-manager/v1/idp/userpools/{userpool_id}:\001*'
  _globals['_USERPOOLSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteUserpoolMetadata\022\025google.protobuf.Empty\202\323\344\223\0026*4/organization-manager/v1/idp/userpools/{userpool_id}'
  _globals['_USERPOOLSERVICE'].methods_by_name['GetDomain']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['GetDomain']._serialized_options = b'\202\323\344\223\002G\022E/organization-manager/v1/idp/userpools/{userpool_id}/domains/{domain}'
  _globals['_USERPOOLSERVICE'].methods_by_name['ListDomains']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['ListDomains']._serialized_options = b'\202\323\344\223\002>\022</organization-manager/v1/idp/userpools/{userpool_id}/domains'
  _globals['_USERPOOLSERVICE'].methods_by_name['AddDomain']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['AddDomain']._serialized_options = b'\262\322*#\n\031AddUserpoolDomainMetadata\022\006Domain\202\323\344\223\002A\"</organization-manager/v1/idp/userpools/{userpool_id}/domains:\001*'
  _globals['_USERPOOLSERVICE'].methods_by_name['ValidateDomain']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['ValidateDomain']._serialized_options = b'\262\322*(\n\036ValidateUserpoolDomainMetadata\022\006Domain\202\323\344\223\002S\"N/organization-manager/v1/idp/userpools/{userpool_id}/domains/{domain}:validate:\001*'
  _globals['_USERPOOLSERVICE'].methods_by_name['DeleteDomain']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['DeleteDomain']._serialized_options = b'\262\322*5\n\034DeleteUserpoolDomainMetadata\022\025google.protobuf.Empty\202\323\344\223\002G*E/organization-manager/v1/idp/userpools/{userpool_id}/domains/{domain}'
  _globals['_USERPOOLSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002A\022?/organization-manager/v1/idp/userpools/{userpool_id}/operations'
  _globals['_USERPOOLSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002I\022G/organization-manager/v1/idp/userpools/{resource_id}:listAccessBindings'
  _globals['_USERPOOLSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002K\"F/organization-manager/v1/idp/userpools/{resource_id}:setAccessBindings:\001*'
  _globals['_USERPOOLSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002N2I/organization-manager/v1/idp/userpools/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETUSERPOOLREQUEST']._serialized_start=366
  _globals['_GETUSERPOOLREQUEST']._serialized_end=421
  _globals['_LISTUSERPOOLSREQUEST']._serialized_start=424
  _globals['_LISTUSERPOOLSREQUEST']._serialized_end=576
  _globals['_LISTUSERPOOLSRESPONSE']._serialized_start=578
  _globals['_LISTUSERPOOLSRESPONSE']._serialized_end=696
  _globals['_CREATEUSERPOOLREQUEST']._serialized_start=699
  _globals['_CREATEUSERPOOLREQUEST']._serialized_end=1471
  _globals['_CREATEUSERPOOLREQUEST_LABELSENTRY']._serialized_start=1426
  _globals['_CREATEUSERPOOLREQUEST_LABELSENTRY']._serialized_end=1471
  _globals['_CREATEUSERPOOLMETADATA']._serialized_start=1473
  _globals['_CREATEUSERPOOLMETADATA']._serialized_end=1518
  _globals['_UPDATEUSERPOOLREQUEST']._serialized_start=1521
  _globals['_UPDATEUSERPOOLREQUEST']._serialized_end=2294
  _globals['_UPDATEUSERPOOLREQUEST_LABELSENTRY']._serialized_start=1426
  _globals['_UPDATEUSERPOOLREQUEST_LABELSENTRY']._serialized_end=1471
  _globals['_UPDATEUSERPOOLMETADATA']._serialized_start=2296
  _globals['_UPDATEUSERPOOLMETADATA']._serialized_end=2341
  _globals['_DELETEUSERPOOLREQUEST']._serialized_start=2343
  _globals['_DELETEUSERPOOLREQUEST']._serialized_end=2401
  _globals['_DELETEUSERPOOLMETADATA']._serialized_start=2403
  _globals['_DELETEUSERPOOLMETADATA']._serialized_end=2448
  _globals['_GETUSERPOOLDOMAINREQUEST']._serialized_start=2450
  _globals['_GETUSERPOOLDOMAINREQUEST']._serialized_end=2513
  _globals['_LISTUSERPOOLDOMAINSREQUEST']._serialized_start=2516
  _globals['_LISTUSERPOOLDOMAINSREQUEST']._serialized_end=2656
  _globals['_LISTUSERPOOLDOMAINSRESPONSE']._serialized_start=2658
  _globals['_LISTUSERPOOLDOMAINSRESPONSE']._serialized_end=2778
  _globals['_ADDUSERPOOLDOMAINREQUEST']._serialized_start=2780
  _globals['_ADDUSERPOOLDOMAINREQUEST']._serialized_end=2843
  _globals['_ADDUSERPOOLDOMAINMETADATA']._serialized_start=2845
  _globals['_ADDUSERPOOLDOMAINMETADATA']._serialized_end=2909
  _globals['_VALIDATEUSERPOOLDOMAINREQUEST']._serialized_start=2911
  _globals['_VALIDATEUSERPOOLDOMAINREQUEST']._serialized_end=2979
  _globals['_VALIDATEUSERPOOLDOMAINMETADATA']._serialized_start=2981
  _globals['_VALIDATEUSERPOOLDOMAINMETADATA']._serialized_end=3050
  _globals['_DELETEUSERPOOLDOMAINREQUEST']._serialized_start=3052
  _globals['_DELETEUSERPOOLDOMAINREQUEST']._serialized_end=3118
  _globals['_DELETEUSERPOOLDOMAINMETADATA']._serialized_start=3120
  _globals['_DELETEUSERPOOLDOMAINMETADATA']._serialized_end=3187
  _globals['_LISTUSERPOOLOPERATIONSREQUEST']._serialized_start=3189
  _globals['_LISTUSERPOOLOPERATIONSREQUEST']._serialized_end=3314
  _globals['_LISTUSERPOOLOPERATIONSRESPONSE']._serialized_start=3316
  _globals['_LISTUSERPOOLOPERATIONSRESPONSE']._serialized_end=3428
  _globals['_USERPOOLSERVICE']._serialized_start=3431
  _globals['_USERPOOLSERVICE']._serialized_end=6610
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.idp.userpool_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetUserpoolRequest(google.protobuf.message.Message):
    """Request to get a userpool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool to return.
    To get the userpool ID, make a [UserpoolService.List] request.
    """
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["userpool_id", b"userpool_id"]) -> None: ...

global___GetUserpoolRequest = GetUserpoolRequest

@typing.final
class ListUserpoolsRequest(google.protobuf.message.Message):
    """Request to list userpools."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization to list userpools in."""
    page_size: builtins.int
    """The maximum number of results per page to return.
    If the number of available results is larger than [page_size],
    the service returns a [ListUserpoolsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListUserpoolsResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response."""
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListUserpoolsRequest = ListUserpoolsRequest

@typing.final
class ListUserpoolsResponse(google.protobuf.message.Message):
    """Response message for [UserpoolService.List]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOLS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.
    If the number of results is larger than [ListUserpoolsRequest.page_size],
    use the [next_page_token] as the value for the [ListUserpoolsRequest.page_token]
    query parameter in the next list request.
    """
    @property
    def userpools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.idp.userpool_pb2.Userpool]:
        """List of userpools."""

    def __init__(
        self,
        *,
        userpools: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.idp.userpool_pb2.Userpool] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "userpools", b"userpools"]) -> None: ...

global___ListUserpoolsResponse = ListUserpoolsResponse

@typing.final
class CreateUserpoolRequest(google.protobuf.message.Message):
    """Request to create a userpool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DEFAULT_SUBDOMAIN_FIELD_NUMBER: builtins.int
    USER_SETTINGS_FIELD_NUMBER: builtins.int
    PASSWORD_QUALITY_POLICY_FIELD_NUMBER: builtins.int
    PASSWORD_LIFETIME_POLICY_FIELD_NUMBER: builtins.int
    BRUTEFORCE_PROTECTION_POLICY_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization to create a userpool in."""
    name: builtins.str
    """Name of the userpool.
    The name must be unique within the organization.
    """
    description: builtins.str
    """Description of the userpool."""
    default_subdomain: builtins.str
    """Default subdomain for the userpool."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as key:value pairs."""

    @property
    def user_settings(self) -> yandex.cloud.organizationmanager.v1.idp.userpool_pb2.UserSettings:
        """User settings for the userpool."""

    @property
    def password_quality_policy(self) -> yandex.cloud.organizationmanager.v1.idp.userpool_pb2.PasswordQualityPolicy:
        """Password quality policy for the userpool."""

    @property
    def password_lifetime_policy(self) -> yandex.cloud.organizationmanager.v1.idp.userpool_pb2.PasswordLifetimePolicy:
        """Password lifetime policy for the userpool."""

    @property
    def bruteforce_protection_policy(self) -> yandex.cloud.organizationmanager.v1.idp.userpool_pb2.BruteforceProtectionPolicy:
        """Bruteforce protection policy for the userpool."""

    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        default_subdomain: builtins.str = ...,
        user_settings: yandex.cloud.organizationmanager.v1.idp.userpool_pb2.UserSettings | None = ...,
        password_quality_policy: yandex.cloud.organizationmanager.v1.idp.userpool_pb2.PasswordQualityPolicy | None = ...,
        password_lifetime_policy: yandex.cloud.organizationmanager.v1.idp.userpool_pb2.PasswordLifetimePolicy | None = ...,
        bruteforce_protection_policy: yandex.cloud.organizationmanager.v1.idp.userpool_pb2.BruteforceProtectionPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bruteforce_protection_policy", b"bruteforce_protection_policy", "password_lifetime_policy", b"password_lifetime_policy", "password_quality_policy", b"password_quality_policy", "user_settings", b"user_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bruteforce_protection_policy", b"bruteforce_protection_policy", "default_subdomain", b"default_subdomain", "description", b"description", "labels", b"labels", "name", b"name", "organization_id", b"organization_id", "password_lifetime_policy", b"password_lifetime_policy", "password_quality_policy", b"password_quality_policy", "user_settings", b"user_settings"]) -> None: ...

global___CreateUserpoolRequest = CreateUserpoolRequest

@typing.final
class CreateUserpoolMetadata(google.protobuf.message.Message):
    """Metadata for the [UserpoolService.Create] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool that is being created."""
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["userpool_id", b"userpool_id"]) -> None: ...

global___CreateUserpoolMetadata = CreateUserpoolMetadata

@typing.final
class UpdateUserpoolRequest(google.protobuf.message.Message):
    """Request to update a userpool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    USER_SETTINGS_FIELD_NUMBER: builtins.int
    PASSWORD_QUALITY_POLICY_FIELD_NUMBER: builtins.int
    PASSWORD_LIFETIME_POLICY_FIELD_NUMBER: builtins.int
    BRUTEFORCE_PROTECTION_POLICY_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool to update.
    To get the userpool ID, make a [UserpoolService.List] request.
    """
    name: builtins.str
    """Name of the userpool.
    The name must be unique within the organization.
    """
    description: builtins.str
    """Description of the userpool."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the userpool are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as key:value pairs."""

    @property
    def user_settings(self) -> yandex.cloud.organizationmanager.v1.idp.userpool_pb2.UserSettings:
        """User settings for the userpool."""

    @property
    def password_quality_policy(self) -> yandex.cloud.organizationmanager.v1.idp.userpool_pb2.PasswordQualityPolicy:
        """Password quality policy for the userpool."""

    @property
    def password_lifetime_policy(self) -> yandex.cloud.organizationmanager.v1.idp.userpool_pb2.PasswordLifetimePolicy:
        """Password lifetime policy for the userpool."""

    @property
    def bruteforce_protection_policy(self) -> yandex.cloud.organizationmanager.v1.idp.userpool_pb2.BruteforceProtectionPolicy:
        """Bruteforce protection policy for the userpool."""

    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        user_settings: yandex.cloud.organizationmanager.v1.idp.userpool_pb2.UserSettings | None = ...,
        password_quality_policy: yandex.cloud.organizationmanager.v1.idp.userpool_pb2.PasswordQualityPolicy | None = ...,
        password_lifetime_policy: yandex.cloud.organizationmanager.v1.idp.userpool_pb2.PasswordLifetimePolicy | None = ...,
        bruteforce_protection_policy: yandex.cloud.organizationmanager.v1.idp.userpool_pb2.BruteforceProtectionPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bruteforce_protection_policy", b"bruteforce_protection_policy", "password_lifetime_policy", b"password_lifetime_policy", "password_quality_policy", b"password_quality_policy", "update_mask", b"update_mask", "user_settings", b"user_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bruteforce_protection_policy", b"bruteforce_protection_policy", "description", b"description", "labels", b"labels", "name", b"name", "password_lifetime_policy", b"password_lifetime_policy", "password_quality_policy", b"password_quality_policy", "update_mask", b"update_mask", "user_settings", b"user_settings", "userpool_id", b"userpool_id"]) -> None: ...

global___UpdateUserpoolRequest = UpdateUserpoolRequest

@typing.final
class UpdateUserpoolMetadata(google.protobuf.message.Message):
    """Metadata for the [UserpoolService.Update] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool that is being updated."""
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["userpool_id", b"userpool_id"]) -> None: ...

global___UpdateUserpoolMetadata = UpdateUserpoolMetadata

@typing.final
class DeleteUserpoolRequest(google.protobuf.message.Message):
    """Request to delete a userpool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool to delete.
    To get the userpool ID, make a [UserpoolService.List] request.
    """
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["userpool_id", b"userpool_id"]) -> None: ...

global___DeleteUserpoolRequest = DeleteUserpoolRequest

@typing.final
class DeleteUserpoolMetadata(google.protobuf.message.Message):
    """Metadata for the [UserpoolService.Delete] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool that is being deleted."""
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["userpool_id", b"userpool_id"]) -> None: ...

global___DeleteUserpoolMetadata = DeleteUserpoolMetadata

@typing.final
class GetUserpoolDomainRequest(google.protobuf.message.Message):
    """Request to get a domain for a userpool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool to get a domain for."""
    domain: builtins.str
    """Domain name."""
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "userpool_id", b"userpool_id"]) -> None: ...

global___GetUserpoolDomainRequest = GetUserpoolDomainRequest

@typing.final
class ListUserpoolDomainsRequest(google.protobuf.message.Message):
    """Request to list domains for a userpool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool to list domains for."""
    page_size: builtins.int
    """The maximum number of results per page to return."""
    page_token: builtins.str
    """Page token for pagination."""
    filter: builtins.str
    """A filter expression that filters resources listed in the response."""
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "userpool_id", b"userpool_id"]) -> None: ...

global___ListUserpoolDomainsRequest = ListUserpoolDomainsRequest

@typing.final
class ListUserpoolDomainsResponse(google.protobuf.message.Message):
    """Response message for [UserpoolService.ListDomains]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAINS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list."""
    @property
    def domains(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.idp.userpool_pb2.Domain]:
        """List of domains."""

    def __init__(
        self,
        *,
        domains: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.idp.userpool_pb2.Domain] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domains", b"domains", "next_page_token", b"next_page_token"]) -> None: ...

global___ListUserpoolDomainsResponse = ListUserpoolDomainsResponse

@typing.final
class AddUserpoolDomainRequest(google.protobuf.message.Message):
    """Request to add a domain to a userpool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool to add a domain to."""
    domain: builtins.str
    """Domain name to add."""
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "userpool_id", b"userpool_id"]) -> None: ...

global___AddUserpoolDomainRequest = AddUserpoolDomainRequest

@typing.final
class AddUserpoolDomainMetadata(google.protobuf.message.Message):
    """Metadata for the [UserpoolService.AddDomain] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool."""
    domain: builtins.str
    """Domain name being added."""
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "userpool_id", b"userpool_id"]) -> None: ...

global___AddUserpoolDomainMetadata = AddUserpoolDomainMetadata

@typing.final
class ValidateUserpoolDomainRequest(google.protobuf.message.Message):
    """Request to validate a domain for a userpool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool to validate a domain for."""
    domain: builtins.str
    """Domain name to validate."""
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "userpool_id", b"userpool_id"]) -> None: ...

global___ValidateUserpoolDomainRequest = ValidateUserpoolDomainRequest

@typing.final
class ValidateUserpoolDomainMetadata(google.protobuf.message.Message):
    """Metadata for the [UserpoolService.ValidateDomain] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool."""
    domain: builtins.str
    """Domain name being validated."""
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "userpool_id", b"userpool_id"]) -> None: ...

global___ValidateUserpoolDomainMetadata = ValidateUserpoolDomainMetadata

@typing.final
class DeleteUserpoolDomainRequest(google.protobuf.message.Message):
    """Request to delete a domain from a userpool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool to delete a domain from."""
    domain: builtins.str
    """Domain name to delete."""
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "userpool_id", b"userpool_id"]) -> None: ...

global___DeleteUserpoolDomainRequest = DeleteUserpoolDomainRequest

@typing.final
class DeleteUserpoolDomainMetadata(google.protobuf.message.Message):
    """Metadata for the [UserpoolService.DeleteDomain] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool."""
    domain: builtins.str
    """Domain name being deleted."""
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "userpool_id", b"userpool_id"]) -> None: ...

global___DeleteUserpoolDomainMetadata = DeleteUserpoolDomainMetadata

@typing.final
class ListUserpoolOperationsRequest(google.protobuf.message.Message):
    """Request to list operations for a userpool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return."""
    page_token: builtins.str
    """Page token for pagination."""
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "userpool_id", b"userpool_id"]) -> None: ...

global___ListUserpoolOperationsRequest = ListUserpoolOperationsRequest

@typing.final
class ListUserpoolOperationsResponse(google.protobuf.message.Message):
    """Response message for [UserpoolService.ListOperations]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list."""
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListUserpoolOperationsResponse = ListUserpoolOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.idp.user_pb2
import yandex.cloud.organizationmanager.v1.idp.user_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class UserServiceStub:
    """A set of methods for managing users in the Identity Provider system."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.GetUserRequest,
        yandex.cloud.organizationmanager.v1.idp.user_pb2.User,
    ]
    """Returns the specified user.

    To get the list of available users, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ListUsersRequest,
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ListUsersResponse,
    ]
    """Retrieves the list of users in the specified userpool."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.CreateUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a user in the specified userpool."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.UpdateUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified user."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.DeleteUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified user."""

    SetOwnPassword: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.SetOwnPasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets the password for the authenticated user."""

    SetOthersPassword: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.SetOthersPasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets the password for another user."""

    Suspend: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.SuspendUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Suspends the specified user."""

    Reactivate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ReactivateUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Reactivates a previously suspended user."""

    GeneratePassword: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.GeneratePasswordRequest,
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.GeneratePasswordResponse,
    ]
    """Generates a new password."""

    GetSelfPasswordMetadata: grpc.UnaryUnaryMultiCallable[
        google.protobuf.empty_pb2.Empty,
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.PasswordMetadata,
    ]
    """Returns metadata about the authenticated user's password."""

    ConvertToExternal: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ConvertToExternalUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Converts a user to use external authentication."""

    SetPasswordHash: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.SetPasswordHashRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets a password hash for the specified user."""

    ResolveExternalIds: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ResolveExternalIdsRequest,
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ResolveExternalIdsResponse,
    ]
    """Resolves external IDs to internal user IDs."""

class UserServiceAsyncStub:
    """A set of methods for managing users in the Identity Provider system."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.GetUserRequest,
        yandex.cloud.organizationmanager.v1.idp.user_pb2.User,
    ]
    """Returns the specified user.

    To get the list of available users, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ListUsersRequest,
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ListUsersResponse,
    ]
    """Retrieves the list of users in the specified userpool."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.CreateUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a user in the specified userpool."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.UpdateUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified user."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.DeleteUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified user."""

    SetOwnPassword: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.SetOwnPasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets the password for the authenticated user."""

    SetOthersPassword: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.SetOthersPasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets the password for another user."""

    Suspend: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.SuspendUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Suspends the specified user."""

    Reactivate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ReactivateUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Reactivates a previously suspended user."""

    GeneratePassword: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.GeneratePasswordRequest,
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.GeneratePasswordResponse,
    ]
    """Generates a new password."""

    GetSelfPasswordMetadata: grpc.aio.UnaryUnaryMultiCallable[
        google.protobuf.empty_pb2.Empty,
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.PasswordMetadata,
    ]
    """Returns metadata about the authenticated user's password."""

    ConvertToExternal: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ConvertToExternalUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Converts a user to use external authentication."""

    SetPasswordHash: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.SetPasswordHashRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets a password hash for the specified user."""

    ResolveExternalIds: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ResolveExternalIdsRequest,
        yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ResolveExternalIdsResponse,
    ]
    """Resolves external IDs to internal user IDs."""

class UserServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing users in the Identity Provider system."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.user_service_pb2.GetUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.user_pb2.User, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.user_pb2.User]]:
        """Returns the specified user.

        To get the list of available users, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ListUsersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ListUsersResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ListUsersResponse]]:
        """Retrieves the list of users in the specified userpool."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.user_service_pb2.CreateUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a user in the specified userpool."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.user_service_pb2.UpdateUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified user."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.user_service_pb2.DeleteUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified user."""

    @abc.abstractmethod
    def SetOwnPassword(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.user_service_pb2.SetOwnPasswordRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets the password for the authenticated user."""

    @abc.abstractmethod
    def SetOthersPassword(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.user_service_pb2.SetOthersPasswordRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets the password for another user."""

    @abc.abstractmethod
    def Suspend(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.user_service_pb2.SuspendUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Suspends the specified user."""

    @abc.abstractmethod
    def Reactivate(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ReactivateUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Reactivates a previously suspended user."""

    @abc.abstractmethod
    def GeneratePassword(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.user_service_pb2.GeneratePasswordRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.user_service_pb2.GeneratePasswordResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.user_service_pb2.GeneratePasswordResponse]]:
        """Generates a new password."""

    @abc.abstractmethod
    def GetSelfPasswordMetadata(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.user_service_pb2.PasswordMetadata, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.user_service_pb2.PasswordMetadata]]:
        """Returns metadata about the authenticated user's password."""

    @abc.abstractmethod
    def ConvertToExternal(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ConvertToExternalUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Converts a user to use external authentication."""

    @abc.abstractmethod
    def SetPasswordHash(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.user_service_pb2.SetPasswordHashRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets a password hash for the specified user."""

    @abc.abstractmethod
    def ResolveExternalIds(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ResolveExternalIdsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ResolveExternalIdsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.user_service_pb2.ResolveExternalIdsResponse]]:
        """Resolves external IDs to internal user IDs."""

def add_UserServiceServicer_to_server(servicer: UserServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/mysql/v1alpha/backup_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/mysql/v1alpha/backup_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.mysql.v1alpha import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1alpha_dot_backup__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/mdb/mysql/v1alpha/backup_service.proto\x12\x1eyandex.cloud.mdb.mysql.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a+yandex/cloud/mdb/mysql/v1alpha/backup.proto\"+\n\x10GetBackupRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"s\n\x12ListBackupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"r\n\x13ListBackupsResponse\x12\x37\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32&.yandex.cloud.mdb.mysql.v1alpha.Backup\x12\"\n\x0fnext_page_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=1002\xbf\x02\n\rBackupService\x12\x93\x01\n\x03Get\x12\x30.yandex.cloud.mdb.mysql.v1alpha.GetBackupRequest\x1a&.yandex.cloud.mdb.mysql.v1alpha.Backup\"2\x82\xd3\xe4\x93\x02,\x12*/managed-mysql/v1alpha/backups/{backup_id}\x12\x97\x01\n\x04List\x12\x32.yandex.cloud.mdb.mysql.v1alpha.ListBackupsRequest\x1a\x33.yandex.cloud.mdb.mysql.v1alpha.ListBackupsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/managed-mysql/v1alpha/backupsBn\n\"yandex.cloud.api.mdb.mysql.v1alphaZHgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1alpha;mysqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mysql.v1alpha.backup_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.mysql.v1alphaZHgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1alpha;mysql'
  _globals['_GETBACKUPREQUEST'].fields_by_name['backup_id']._loaded_options = None
  _globals['_GETBACKUPREQUEST'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTBACKUPSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTBACKUPSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTBACKUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTBACKUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTBACKUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTBACKUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTBACKUPSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_LISTBACKUPSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_BACKUPSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_BACKUPSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002,\022*/managed-mysql/v1alpha/backups/{backup_id}'
  _globals['_BACKUPSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_BACKUPSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002 \022\036/managed-mysql/v1alpha/backups'
  _globals['_GETBACKUPREQUEST']._serialized_start=193
  _globals['_GETBACKUPREQUEST']._serialized_end=236
  _globals['_LISTBACKUPSREQUEST']._serialized_start=238
  _globals['_LISTBACKUPSREQUEST']._serialized_end=353
  _globals['_LISTBACKUPSRESPONSE']._serialized_start=355
  _globals['_LISTBACKUPSRESPONSE']._serialized_end=469
  _globals['_BACKUPSERVICE']._serialized_start=472
  _globals['_BACKUPSERVICE']._serialized_end=791
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class User(google.protobuf.message.Message):
    """A user in the Identity Provider system.

    Users are created within a userpool and can authenticate to access cloud resources.
    Each user has a unique identifier, credentials, and profile information.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[User._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: User._Status.ValueType  # 0
        """The status is not specified."""
        CREATING: User._Status.ValueType  # 4
        """The user is in the process of being created."""
        ACTIVE: User._Status.ValueType  # 1
        """The user is active and can authenticate.
        Active users have full access to the system according to their permissions.
        """
        SUSPENDED: User._Status.ValueType  # 2
        """The user is suspended and cannot authenticate.
        Suspended users retain their data but cannot access the system.
        """
        DELETING: User._Status.ValueType  # 3
        """The user is in the process of being deleted.
        This is a transitional state before the user is completely removed from the system.
        """

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Represents the current status of a user in the Identity Provider system."""

    STATUS_UNSPECIFIED: User.Status.ValueType  # 0
    """The status is not specified."""
    CREATING: User.Status.ValueType  # 4
    """The user is in the process of being created."""
    ACTIVE: User.Status.ValueType  # 1
    """The user is active and can authenticate.
    Active users have full access to the system according to their permissions.
    """
    SUSPENDED: User.Status.ValueType  # 2
    """The user is suspended and cannot authenticate.
    Suspended users retain their data but cannot access the system.
    """
    DELETING: User.Status.ValueType  # 3
    """The user is in the process of being deleted.
    This is a transitional state before the user is completely removed from the system.
    """

    ID_FIELD_NUMBER: builtins.int
    USERPOOL_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    FULL_NAME_FIELD_NUMBER: builtins.int
    GIVEN_NAME_FIELD_NUMBER: builtins.int
    FAMILY_NAME_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    PHONE_NUMBER_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the user.
    This ID is generated automatically when the user is created.
    """
    userpool_id: builtins.str
    """ID of the userpool this user belongs to.
    To get the userpool ID, make a [UserpoolService.List] request.
    """
    status: global___User.Status.ValueType
    """Current status of the user.
    Determines whether the user can authenticate and access the system.
    """
    username: builtins.str
    """Username used for authentication.
    Usually in the format of an email address.
    """
    full_name: builtins.str
    """User's full name (display name).
    This is typically shown in the UI and used for identification purposes.
    """
    given_name: builtins.str
    """User's first name.
    Part of the user's profile information.
    """
    family_name: builtins.str
    """User's last name.
    Part of the user's profile information.
    """
    email: builtins.str
    """User's email address."""
    phone_number: builtins.str
    """User's phone number."""
    external_id: builtins.str
    """External identifier for federation with external identity systems.
    This ID can be used to link this user with an account in an external system.
    """
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the user was created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the user was last updated."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        userpool_id: builtins.str = ...,
        status: global___User.Status.ValueType = ...,
        username: builtins.str = ...,
        full_name: builtins.str = ...,
        given_name: builtins.str = ...,
        family_name: builtins.str = ...,
        email: builtins.str = ...,
        phone_number: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        external_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "email", b"email", "external_id", b"external_id", "family_name", b"family_name", "full_name", b"full_name", "given_name", b"given_name", "id", b"id", "phone_number", b"phone_number", "status", b"status", "updated_at", b"updated_at", "username", b"username", "userpool_id", b"userpool_id"]) -> None: ...

global___User = User



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/analysis/assistants.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/analysis/assistants.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/speechsense/v1/analysis/assistants.proto\x12$yandex.cloud.speechsense.v1.analysis\"^\n\nAssistants\x12P\n\x11\x61ssistant_results\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.speechsense.v1.analysis.AssistantResult\"t\n\x0f\x41ssistantResult\x12\x14\n\x0c\x61ssistant_id\x18\x01 \x01(\t\x12K\n\x07results\x18\x02 \x03(\x0b\x32:.yandex.cloud.speechsense.v1.analysis.AssistantFieldResult\"}\n\x14\x41ssistantFieldResult\x12\x10\n\x08\x66ield_id\x18\x01 \x01(\t\x12\x17\n\rstring_result\x18\x02 \x01(\tH\x00\x12\x14\n\nint_result\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x66loat_result\x18\x04 \x01(\x01H\x00\x42\x0c\n\nfield_typeB\x91\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x0f\x41ssistantsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.assistants_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\017AssistantsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_ASSISTANTS']._serialized_start=95
  _globals['_ASSISTANTS']._serialized_end=189
  _globals['_ASSISTANTRESULT']._serialized_start=191
  _globals['_ASSISTANTRESULT']._serialized_end=307
  _globals['_ASSISTANTFIELDRESULT']._serialized_start=309
  _globals['_ASSISTANTFIELDRESULT']._serialized_end=434
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class AgentRegistrationServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Register: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.RegisterRequest,
        yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.RegisterResponse,
    ]
    """Registers specified agent."""

    ExternalAgentRegister: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.ExternalAgentRegisterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Registers external agent."""

class AgentRegistrationServiceAsyncStub:
    Register: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.RegisterRequest,
        yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.RegisterResponse,
    ]
    """Registers specified agent."""

    ExternalAgentRegister: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.ExternalAgentRegisterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Registers external agent."""

class AgentRegistrationServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Register(
        self,
        request: yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.RegisterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.RegisterResponse, collections.abc.Awaitable[yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.RegisterResponse]]:
        """Registers specified agent."""

    @abc.abstractmethod
    def ExternalAgentRegister(
        self,
        request: yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.ExternalAgentRegisterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Registers external agent."""

def add_AgentRegistrationServiceServicer_to_server(servicer: AgentRegistrationServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/assistants_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/assistants_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.speechsense.v1 import assistant_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_assistant__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/speechsense/v1/assistants_service.proto\x12\x1byandex.cloud.speechsense.v1\x1a\x1cgoogle/api/annotations.proto\x1a+yandex/cloud/speechsense/v1/assistant.proto\"+\n\x15ListAssistantsRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"T\n\x16ListAssistantsResponse\x12:\n\nassistants\x18\x01 \x03(\x0b\x32&.yandex.cloud.speechsense.v1.Assistant\"\x13\n\x11ListModelsRequest\"H\n\x12ListModelsResponse\x12\x32\n\x06models\x18\x01 \x03(\x0b\x32\".yandex.cloud.speechsense.v1.Model2\xd3\x02\n\x11\x41ssistantsService\x12\x9b\x01\n\x04List\x12\x32.yandex.cloud.speechsense.v1.ListAssistantsRequest\x1a\x33.yandex.cloud.speechsense.v1.ListAssistantsResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/speechsense/v1/assistants/list:\x01*\x12\x9f\x01\n\nListModels\x12..yandex.cloud.speechsense.v1.ListModelsRequest\x1a/.yandex.cloud.speechsense.v1.ListModelsResponse\"0\x82\xd3\xe4\x93\x02*\"%/speechsense/v1/assistants/listModels:\x01*B\x86\x01\n\x1fyandex.cloud.api.speechsense.v1B\x16\x41ssistantsServiceProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.assistants_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\026AssistantsServiceProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _globals['_ASSISTANTSSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_ASSISTANTSSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002$\"\037/speechsense/v1/assistants/list:\001*'
  _globals['_ASSISTANTSSERVICE'].methods_by_name['ListModels']._loaded_options = None
  _globals['_ASSISTANTSSERVICE'].methods_by_name['ListModels']._serialized_options = b'\202\323\344\223\002*\"%/speechsense/v1/assistants/listModels:\001*'
  _globals['_LISTASSISTANTSREQUEST']._serialized_start=160
  _globals['_LISTASSISTANTSREQUEST']._serialized_end=203
  _globals['_LISTASSISTANTSRESPONSE']._serialized_start=205
  _globals['_LISTASSISTANTSRESPONSE']._serialized_end=289
  _globals['_LISTMODELSREQUEST']._serialized_start=291
  _globals['_LISTMODELSREQUEST']._serialized_end=310
  _globals['_LISTMODELSRESPONSE']._serialized_start=312
  _globals['_LISTMODELSRESPONSE']._serialized_end=384
  _globals['_ASSISTANTSSERVICE']._serialized_start=387
  _globals['_ASSISTANTSSERVICE']._serialized_end=726
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Secret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the secret."""
    key: builtins.str
    """Name of the key."""
    version_id: builtins.str
    """Version of the secret."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        key: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "key", b"key", "version_id", b"version_id"]) -> None: ...

global___Secret = Secret

@typing.final
class ContainerSolutionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class SecretsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Secret: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Secret | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class EnvironmentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    PRODUCT_ID_FIELD_NUMBER: builtins.int
    SECRETS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    product_id: builtins.str
    """ID of the product."""
    @property
    def secrets(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Secret]:
        """A list of the secrets."""

    @property
    def environment(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """A list of the environmets."""

    def __init__(
        self,
        *,
        product_id: builtins.str = ...,
        secrets: collections.abc.Mapping[builtins.str, global___Secret] | None = ...,
        environment: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["environment", b"environment", "product_id", b"product_id", "secrets", b"secrets"]) -> None: ...

global___ContainerSolutionSpec = ContainerSolutionSpec

@typing.final
class BackupSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    INITIAL_POLICY_IDS_FIELD_NUMBER: builtins.int
    RECOVERY_FROM_BACKUP_FIELD_NUMBER: builtins.int
    BACKUP_ID_FIELD_NUMBER: builtins.int
    INSTANCE_REGISTRATION_ID_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    """If true, backup is enabled."""
    recovery_from_backup: builtins.bool
    """If true, recovery from backup starts on instance."""
    backup_id: builtins.str
    """ID of the backup to recover from."""
    instance_registration_id: builtins.str
    """ID of the instance registration for cloud backup agent installation."""
    @property
    def initial_policy_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of policy IDs to apply after resource registration."""

    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        initial_policy_ids: collections.abc.Iterable[builtins.str] | None = ...,
        recovery_from_backup: builtins.bool = ...,
        backup_id: builtins.str = ...,
        instance_registration_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "enabled", b"enabled", "initial_policy_ids", b"initial_policy_ids", "instance_registration_id", b"instance_registration_id", "recovery_from_backup", b"recovery_from_backup"]) -> None: ...

global___BackupSpec = BackupSpec

@typing.final
class Application(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_SOLUTION_FIELD_NUMBER: builtins.int
    CLOUDBACKUP_FIELD_NUMBER: builtins.int
    @property
    def container_solution(self) -> global___ContainerSolutionSpec:
        """Container specification."""

    @property
    def cloudbackup(self) -> global___BackupSpec:
        """Backup settings."""

    def __init__(
        self,
        *,
        container_solution: global___ContainerSolutionSpec | None = ...,
        cloudbackup: global___BackupSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cloudbackup", b"cloudbackup", "container", b"container", "container_solution", b"container_solution"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloudbackup", b"cloudbackup", "container", b"container", "container_solution", b"container_solution"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["container", b"container"]) -> typing.Literal["container_solution"] | None: ...

global___Application = Application



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/assistant.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/assistant.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/speechsense/v1/assistant.proto\x12\x1byandex.cloud.speechsense.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbb\x03\n\tAssistant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0e\n\x06prompt\x18\x06 \x01(\t\x12;\n\x06\x66ields\x18\x07 \x03(\x0b\x32+.yandex.cloud.speechsense.v1.AssistantField\x12\x0f\n\x07\x65nabled\x18\x08 \x01(\x08\x12\x42\n\x06labels\x18\t \x03(\x0b\x32\x32.yandex.cloud.speechsense.v1.Assistant.LabelsEntry\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12/\n\x0bmodified_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bmodified_by\x18\r \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x0e\x41ssistantField\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12=\n\x04type\x18\x04 \x01(\x0e\x32/.yandex.cloud.speechsense.v1.AssistantFieldType\"6\n\x05Model\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t*\x9e\x01\n\x12\x41ssistantFieldType\x12$\n ASSISTANT_FIELD_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x41SSISTANT_FIELD_TYPE_STRING\x10\x01\x12\x1f\n\x1b\x41SSISTANT_FIELD_TYPE_NUMBER\x10\x02\x12 \n\x1c\x41SSISTANT_FIELD_TYPE_DECIMAL\x10\x03\x42~\n\x1fyandex.cloud.api.speechsense.v1B\x0e\x41ssistantProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.assistant_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\016AssistantProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _globals['_ASSISTANT_LABELSENTRY']._loaded_options = None
  _globals['_ASSISTANT_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_ASSISTANTFIELDTYPE']._serialized_start=740
  _globals['_ASSISTANTFIELDTYPE']._serialized_end=898
  _globals['_ASSISTANT']._serialized_start=110
  _globals['_ASSISTANT']._serialized_end=553
  _globals['_ASSISTANT_LABELSENTRY']._serialized_start=508
  _globals['_ASSISTANT_LABELSENTRY']._serialized_end=553
  _globals['_ASSISTANTFIELD']._serialized_start=555
  _globals['_ASSISTANTFIELD']._serialized_end=681
  _globals['_MODEL']._serialized_start=683
  _globals['_MODEL']._serialized_end=737
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ServiceAccount(google.protobuf.message.Message):
    """A ServiceAccount resource. For more information, see [Service accounts](/docs/iam/concepts/users/service-accounts)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LAST_AUTHENTICATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the service account."""
    folder_id: builtins.str
    """ID of the folder that the service account belongs to."""
    name: builtins.str
    """Name of the service account.
    The name is unique within the cloud. 3-63 characters long.
    """
    description: builtins.str
    """Description of the service account. 0-256 characters long."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs. Maximum of 64 per resource."""

    @property
    def last_authenticated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp for the last authentication of this service account."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        last_authenticated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "last_authenticated_at", b"last_authenticated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "last_authenticated_at", b"last_authenticated_at", "name", b"name"]) -> None: ...

global___ServiceAccount = ServiceAccount



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AssistantFieldType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AssistantFieldTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AssistantFieldType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ASSISTANT_FIELD_TYPE_UNSPECIFIED: _AssistantFieldType.ValueType  # 0
    ASSISTANT_FIELD_TYPE_STRING: _AssistantFieldType.ValueType  # 1
    ASSISTANT_FIELD_TYPE_NUMBER: _AssistantFieldType.ValueType  # 2
    ASSISTANT_FIELD_TYPE_DECIMAL: _AssistantFieldType.ValueType  # 3
    """Floating-point number"""

class AssistantFieldType(_AssistantFieldType, metaclass=_AssistantFieldTypeEnumTypeWrapper): ...

ASSISTANT_FIELD_TYPE_UNSPECIFIED: AssistantFieldType.ValueType  # 0
ASSISTANT_FIELD_TYPE_STRING: AssistantFieldType.ValueType  # 1
ASSISTANT_FIELD_TYPE_NUMBER: AssistantFieldType.ValueType  # 2
ASSISTANT_FIELD_TYPE_DECIMAL: AssistantFieldType.ValueType  # 3
"""Floating-point number"""
global___AssistantFieldType = AssistantFieldType

@typing.final
class Assistant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    MODEL_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PROMPT_FIELD_NUMBER: builtins.int
    FIELDS_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    MODIFIED_AT_FIELD_NUMBER: builtins.int
    MODIFIED_BY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Assistant id"""
    project_id: builtins.str
    """Project id"""
    model_id: builtins.str
    """Model id"""
    name: builtins.str
    """Assistant name"""
    description: builtins.str
    """Assistant description"""
    prompt: builtins.str
    """Prompt"""
    enabled: builtins.bool
    created_by: builtins.str
    """Subject id"""
    modified_by: builtins.str
    """Subject id"""
    @property
    def fields(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssistantField]:
        """Fields that will be set after assistant processing"""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Billing labels"""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        project_id: builtins.str = ...,
        model_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        prompt: builtins.str = ...,
        fields: collections.abc.Iterable[global___AssistantField] | None = ...,
        enabled: builtins.bool = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
        modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        modified_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "modified_at", b"modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "created_by", b"created_by", "description", b"description", "enabled", b"enabled", "fields", b"fields", "id", b"id", "labels", b"labels", "model_id", b"model_id", "modified_at", b"modified_at", "modified_by", b"modified_by", "name", b"name", "project_id", b"project_id", "prompt", b"prompt"]) -> None: ...

global___Assistant = Assistant

@typing.final
class AssistantField(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Field id"""
    name: builtins.str
    """Field name"""
    description: builtins.str
    """Field description"""
    type: global___AssistantFieldType.ValueType
    """Field type"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        type: global___AssistantFieldType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "id", b"id", "name", b"name", "type", b"type"]) -> None: ...

global___AssistantField = AssistantField

@typing.final
class Model(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Model id"""
    name: builtins.str
    """Model name"""
    description: builtins.str
    """Model description"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "id", b"id", "name", b"name"]) -> None: ...

global___Model = Model
